function compList = getComponentNames(this, compKind)
%GETCOMPONENTNAMES returns the list of Software-Component-Type names found
%    in the XML files associated with the arxml.importer object.
%    COMPONENTNAMES = GETCOMPONENTNAMES(IMPORTER) returns
%    the list of component names COMPONENTNAMES found in the XML
%    files associated with the arxml.importer object IMPORTER.
%
%   COMPONENTNAMES is a cell array of strings in which each element is the
%   absolute Short-Name path of the corresponding component:
%   '/root_package_name[/sub_package_name]/component_short_name'.
%
%   Usage:
%      compNames = getComponentNames(importerObj, compKind)
%
%   Inputs:
%      importerObj: arxml.importer object
%      compKind:    Atomic (default), Composition, Parameter, Application,
%                   SensorActuator, ServiceProxy, ComplexDeviceDriver,
%                   and EcuAbstraction.
%                   String specifying the kind of Software-Component-Type 
%                   to return.

%   Copyright 2007-2017 The MathWorks, Inc.

if nargin < 2
    compKind = 'Atomic';
end

validatestring(compKind,[{'Atomic','Composition','Parameter'} ...
    autosar.composition.Utils.getSupportedComponentKinds()], 2);

compList = [];
if strcmp(compKind, 'Atomic')
    compKinds = autosar.composition.Utils.getSupportedComponentKinds();
    for compIdx = 1:length(compKinds)
        compList = [compList;p_getcomponentnames(this, compKinds{compIdx})]; %#ok<AGROW>
    end
else
    try
        compList = p_getcomponentnames(this, compKind);
    catch Me
        %Trim stack to remove internal functions
        Me.throwAsCaller();
    end
end


% LocalWords:  COMPONENTNAMES SETFILE
