function updateModel(this, modelName, varargin)
% UPDATEMODEL(THIS, MODELNAME) updates model MODELNAME with changes in imported
% AUTOSAR description defined in arxml.importer object THIS. The update/merge
% generates a report detailing updates automatically applied to the model and
% required changes that were not made automatically. The imported description
% must contain the AUTOSAR software component mapped by the model.
% 
% Example:
% Update model 'mySWC.slx' with AUTOSAR arxml changes described in
% 'updatedSWC.arxml'
% 
% open_system('mySWC');
% obj = arxml.importer('updatedSWC.arxml');
% obj.updateModel('mySWC');

% The update report launches automatically if no value is given to the
% LaunchReport parameter (default is 'on'). To not launch the report, the LaunchReport
% parameter has to be set to 'off'. Example: 
%
% obj.updateModel('mySWC', 'LaunchReport', 'off');
%

%   Copyright 2013-2017 The MathWorks, Inc.

% Check function arguments
argParser = inputParser;
argParser.addRequired('ModelName', @(x)(ischar(x) || isStringScalar(x)));
argParser.addParameter('LaunchReport', 'on', @(x) any(validatestring(x,{'on','off'})));
argParser.addParameter('PredefinedVariant', '', @(x)(ischar(x) || isStringScalar(x)));
argParser.addParameter('SystemConstValueSets', {}, @(x)(iscell(x)));

% convert strings to chars
modelName = convertStringsToChars(modelName);
for ii = 1 : length(varargin)
    if isstring(varargin{ii})
        varargin{ii} = convertStringsToChars(varargin{ii});
    end
end

% parse
argParser.parse(modelName, varargin{:});

% Strip out any extension that user may have passed in
[~, modelName] = fileparts(modelName);

args = {};
if ~isempty(argParser.Results.PredefinedVariant)
    args = [args 'PredefinedVariant' argParser.Results.PredefinedVariant];
end
if ~isempty(argParser.Results.SystemConstValueSets)
    args = [args 'SystemConstValueSets' argParser.Results.SystemConstValueSets];
end
args = [args 'LaunchReport', argParser.Results.LaunchReport];

try
    p_updateModel(this, modelName, args{:});
catch Me
    %Trim stack to delete internal updateModel functions
    Me.throwAsCaller();
end
% LocalWords:  MODELNAME slx
