
%   Copyright 2016-2017 The MathWorks, Inc.

classdef NvMService < autosar.bsw.ServiceImplementation
% Class to define NvMServices

    properties (Constant)
        FunctionPrototypeMap = containers.Map( autosar.bsw.NvMService.Operations, ...
            autosar.bsw.NvMService.FunctionPrototypes );

        FunctionPrototypeWithBlockIdMap = containers.Map( autosar.bsw.NvMService.Operations, ...
            autosar.bsw.NvMService.FunctionPrototypesWithBlockId );
                
        InputArgSpecMap = containers.Map( autosar.bsw.NvMService.Operations, ...
            autosar.bsw.NvMService.InputArgSpecs );

        OutputArgSpecMap = containers.Map( autosar.bsw.NvMService.Operations, ...
            autosar.bsw.NvMService.OutputArgSpecs );
        
        EnumDatatypeMap = containers.Map( autosar.bsw.NvMService.Operations, ...
            autosar.bsw.NvMService.EnumDatatypes );
    end
    
    properties(Constant, Access=private)
        DefaultClientPortName = 'NvMService';
        DefaultInterfacePath = '/AUTOSAR/Services/NvM';
        InterfaceName = 'NvMService';
        Operations = {'GetDataIndex'
                      'GetErrorStatus'
                      'EraseNvBlock'
                      'InvalidateNvBlock'
                      'ReadBlock'
                      'RestoreBlockDefaults'
                      'SetDataIndex'
                      'SetRamBlockStatus'
                      'WriteBlock'};

        FunctionPrototypes = {'[DataIndexPtr,ERR] = %s_GetDataIndex()'
            '[RequestResultPtr,ERR] = %s_GetErrorStatus()'
            'ERR = %s_EraseNvBlock()'
            'ERR = %s_InvalidateNvBlock()'
            '[DstPtr,ERR] = %s_ReadBlock()'
            '[DestPtr,ERR] = %s_RestoreBlockDefaults()'
            'ERR = %s_SetDataIndex(DataIndex)'
            'ERR = %s_SetRamBlockStatus(BlockChanged)'
            'ERR = %s_WriteBlock(SrcPtr)'};
        
        
        FunctionPrototypesWithBlockId = {'[DataIndexPtr,ERR] = %s_GetDataIndex(BlockId)'
            '[RequestResultPtr,ERR] = %s_GetErrorStatus(BlockId)'
            'ERR = %s_EraseNvBlock(BlockId)'
            'ERR = %s_InvalidateNvBlock(BlockId)'
            '[DstPtr,ERR] = %s_ReadBlock(BlockId)'
            '[DestPtr,ERR] = %s_RestoreBlockDefaults(BlockId)'
            'ERR = %s_SetDataIndex(BlockId, DataIndex)'
            'ERR = %s_SetRamBlockStatus(BlockId, BlockChanged)'
            'ERR = %s_WriteBlock(BlockId, SrcPtr)'};

        InputArgSpecs = {''
            ''
            ''
            ''
            ''
            ''
            'uint8(1)'
            'boolean(true)'
            'uint8(1)'}; % P_NvM_DstPtrType'};
        
        EnumDatatypes = {'','','','','','','','',''};
                     
        OutputArgSpecs = {'uint8(1), uint8(1)'
            'uint8(1), uint8(1)' % P_NvM_RequestResultType, P_Std_ReturnType
            'uint8(1)'
            'uint8(1)'
            'uint8(1), uint8(1)' % P_NvM_DstPtrType, P_Std_ReturnType
            'uint8(1), uint8(1)' % P_NvM_DstPtrType, P_Std_ReturnType
            'uint8(1)'
            'uint8(1)'
            'uint8(1)'};
    end
    
    methods(Access=public)
        
        function this = NvMService()
        end
    
        function updateFunctionCaller(this, blkPath, portName, operationName)

            functionPrototypeTemplate = this.FunctionPrototypeMap(operationName);
            inputArgSpec = this.InputArgSpecMap(operationName);
            outputArgSpec = this.OutputArgSpecMap(operationName);                        
            
            functionPrototype = sprintf(functionPrototypeTemplate, portName);
            
            set_param(blkPath, 'FunctionPrototype', functionPrototype);
            set_param(blkPath, 'InputArgumentSpecifications', inputArgSpec);
            set_param(blkPath, 'OutputArgumentSpecifications', outputArgSpec);
            
        end
        
    end
    
    methods(Static, Access=public)

        function deepCopyInterface(mdlName, dstInterfacePath) %#ok<INUSD>
        % Copy interface and data types to model
        
            arxmlPath = fullfile(autosarroot, '+autosar', '+bsw', '+arxml');
            arxmlFiles = {fullfile(arxmlPath, 'AUTOSAR_BaseTypes.arxml')
                          fullfile(arxmlPath, 'AUTOSAR_Type.arxml')
                          fullfile(arxmlPath, 'AUTOSAR_MOD_PlatformTypes.arxml')
                          fullfile(arxmlPath, 'AUTOSAR_NvM.arxml')};
            
            autosar.bsw.ServiceImplementation.updateReferences(mdlName, arxmlFiles);
        end
        
        function defaultClientPortName = getDefaultClientPortName()
            defaultClientPortName =  autosar.bsw.NvMService.DefaultClientPortName;
        end
       
        function interfaceName = getInterfaceName()
            interfaceName =  autosar.bsw.NvMService.InterfaceName;
        end
        
        function operations = getOperations()
            operations =  autosar.bsw.NvMService.Operations;
        end
        
        % This block does not expose a Datatype parameter because it does
        % not use any Enum types
        function hastypeParameter = hasDatatypeParameter()
            hastypeParameter = false;
        end
        
        function dataTypeCallback(~)
        end
        
        function operationCallback(~)
        end
        
        function desc = getDescription()
            desc = autosar.bsw.NvMAdmin.getDescription();
        end
        
        function type = getType()
            type = 'NvMServiceCaller';
        end

        function blockIconType = getBlockIconType()
            blockIconType = 'NvMCaller';
        end
        
        function help = getHelp()
            help = 'helpview(fullfile(docroot,''ecoder'',''helptargets.map''),''autosar_nvmservice_block'');';
        end
        
        
    end
    
end

% LocalWords:  Nv MServices Dest bsw MService helptargets nvmservice MCaller
