classdef BasicSoftwareValidator < autosar.validation.PhasedValidator
% BasicSoftwareValidator
    
%   Copyright 2016 The MathWorks, Inc.

    methods (Access=protected)
        
        function verifyInitial(this, hModel)
            this.verifyBasicSoftwareMapping(hModel);
        end
        
        function verifyPostProp(this, hModel)
            % 2nd call here (other one is in verifyInitial because function
            % callers may not be synchronized at edit time.
            this.verifyBasicSoftwareMapping(hModel);
        end
        
    end

    methods (Static, Access=private)
        
       function verifyBasicSoftwareMapping(hModel)
           % Model mapping may be out of sync with Basic Software blocks

           mapping = autosar.api.Utils.modelMapping(hModel);
           for index=1:length(mapping.FunctionCallers)
               blockMapping = mapping.FunctionCallers(index);
               
               if autosar.bsw.BasicSoftwareCaller.isBSWCallerBlock(blockMapping.Block)
                   if ~strcmp(blockMapping.MappedTo.ClientPort, get_param(blockMapping.Block, 'PortName')) || ...
                      ~strcmp(blockMapping.MappedTo.Operation, get_param(blockMapping.Block, 'Operation'))
                       DAStudio.error('autosarstandard:validation:basicSoftwareMappingSyncNeeded');
                   end
               end
           end
       end
       
    end
    
end

% LocalWords:  autosarstandard
