classdef ClientOperationValidator < autosar.validation.PhasedValidator

%   Copyright 2013 The MathWorks, Inc.
    
    methods (Access=protected)

        function verifyInitial(self, hModel)
            self.verifyShortNames(hModel);
            self.verifyQualifiedNames(hModel);
        end

    end
    
    methods (Static, Access=private)
        
        function verifyShortNames(hModel)

            clientPortBlks = arblk.findAUTOSARClientBlks( getfullname(hModel) );
            
            cs = autosar.validation.ConfigSetValidator.getActiveConfigSet(hModel);
            maxShortNameLength = get_param(cs, 'AutosarMaxShortNameLength');

            
            % Client Operations
            testStrs = {};
            for ii=1:numel( clientPortBlks )
                obj = get_param(clientPortBlks{ii}, 'object');
                fcn = arblk.parseOperationPrototype( obj.operationPrototype, maxShortNameLength );
                testStrs = [testStrs;...
                            cellstr( obj.portName );...
                            cellstr( fcn.name );...
                           ]; %#ok<AGROW>
            end

            

            % Check RuleSNId1, RuleSNId2, RuleSNId3, RuleSNId4, RuleSNId5, RuleSNId6, RuleSNId7
            idcheckmessage = autosar.validation.AutosarUtils.isValidIdentifier(testStrs, 'shortName', maxShortNameLength);
            if ~isempty(idcheckmessage)
                msg = idcheckmessage;
                DAStudio.error('RTW:fcnClass:finish', msg);
            end

        end
        
        function verifyQualifiedNames(hModel)

            clientPortBlks = arblk.findAUTOSARClientBlks( getfullname(hModel) );
            cs = autosar.validation.ConfigSetValidator.getActiveConfigSet(hModel);
            maxShortNameLength = get_param(cs, 'AutosarMaxShortNameLength');
            
            % client operation blocks
            testStrs = {};
            for ii=1:length( clientPortBlks )
                testStrs = [testStrs;...
                            cellstr( get_param( clientPortBlks(ii), 'interfacePath' ) );...
                           ]; %#ok<AGROW>
            end

            % Check RuleASNPId1, RuleASNPId2, RuleASNPId3, RuleASNPId4
            idcheckmessage = autosar.validation.AutosarUtils.isValidIdentifier(testStrs, 'absPathShortName', maxShortNameLength);
            if ~isempty(idcheckmessage)
                msg = idcheckmessage;
                DAStudio.error('RTW:fcnClass:finish', msg);
            end
            
            
        end
        
    end
    
end

% LocalWords:  ASNP
