classdef DataInterfaceFactory < handle
    % DATAINTERFACEFACTORY
    %
    %   Contains the components of an RTW.DataInterface and instantiates it
    %   once complete.
    %
    %   Timing property of RTW.DataInterface is read-only, so we need to
    %   only instantiate when absolutely ready.
    %
    % Copyright 2017 The MathWorks, Inc.
    
    properties (SetAccess = immutable)
        SID char;
        GraphicalName char;
        Implementation RTW.DataImplementation;
    end
    
    properties (Access = public)
    
        Timing RTW.TimingInterface;
        Type coder.types.Type;
        IsQueued logical;
        QueueLength uint32;
    end
    
    
    methods (Access = public)
        
        function obj = DataInterfaceFactory(lSID, lGraphicalName, lImplementation, lTiming)
            % DATAINTERFACEFACTORY
            obj.SID = lSID;
            obj.GraphicalName = lGraphicalName;
            obj.Implementation = lImplementation;
            obj.Timing = lTiming;   % Public property - don't make immutable
        end
        
        
        function lCodeInfoDataInterface = build(obj) 
            % BUILD
            lCodeInfoDataInterface = RTW.DataInterface( ...
                obj.SID, ...
                obj.GraphicalName, ...
                obj.Implementation, ...
                obj.Timing);
            lCodeInfoDataInterface.Type = obj.Type;
            lCodeInfoDataInterface.IsQueued = obj.IsQueued;
            lCodeInfoDataInterface.QueueLength = obj.QueueLength;
        end
        
    end
    
end