classdef AUTOSARInfoSerializer < handle
    % AUTOSARINFOSERIALIZER
    % Copyright 2017 The MathWorks, Inc.
    
    properties (Access = private)
        CodeInfoWrapper;
        InfoStructWrapper;
        DataTypeSerializer;
        OutputFunctionSerializer;
    end
    
    
    methods
        function obj = AUTOSARInfoSerializer(lCodeInfoWrapper, ...
                lInfoStructWrapper)
            % AUTOSARINFOSERIALIZER
            obj.CodeInfoWrapper = lCodeInfoWrapper;
            obj.InfoStructWrapper = lInfoStructWrapper;
            obj.DataTypeSerializer = coder.internal.xrelexport.DataTypeSerializer(obj.CodeInfoWrapper);
            obj.OutputFunctionSerializer = coder.internal.xrelexport.OutputFunctionSerializer(obj.CodeInfoWrapper);
        end
        
        
        function write(obj, writer)
            % WRITE
            writer.wNewLine;
            lAutosarInitRunnableSymbol = obj.CodeInfoWrapper.getInitializeFunction(1).Prototype.Name;
            writer.wLine('xrel_info.AutosarInitRunnableSymbol = ''%s'';', lAutosarInitRunnableSymbol);
            obj.OutputFunctionSerializer.write(writer, 'xrel_info');
            
            if obj.InfoStructWrapper.isNonReusableCodeInterface
                writer.wLine('xrel_info.IsReusable = false;');
                lBSDW = [];
                lSSDW = [];
                lZCDW = [];
            else
                writer.wLine('xrel_info.IsReusable = true;');
                lBSDW = obj.CodeInfoWrapper.getBlockStatesDW;
                lSSDW = obj.CodeInfoWrapper.getSignalStatesDW;
                lZCDW = obj.CodeInfoWrapper.getZCStatesDW;
            end
            
            obj.writeDWorkData(writer, 'Block', lBSDW);
            obj.writeDWorkData(writer, 'Signal', lSSDW);
            obj.writeDWorkData(writer, 'ZC', lZCDW);
            writer.wNewLine;
            
            % For AUTOSAR, serialize data types too
            obj.DataTypeSerializer.writeStructs(writer, 'xrel_info.StructTypes');
            obj.DataTypeSerializer.writeEnums(writer, 'xrel_info.EnumTypes');
            obj.DataTypeSerializer.writeAliases(writer, 'xrel_info.AliasTypes');
            obj.DataTypeSerializer.writeFixDts(writer, 'xrel_info.FixTypes');
            writer.wNewLine;
        end
        
    end
    
    methods (Static, Access = private)
        function writeDWorkData(writer, lPrefix, lDW)
            if isempty(lDW)
                % Either we are not using a reusable code interface, or
                % we are using a reusable code interface but there is
                % no DWork storing the state because there is no state.
                writer.wLine('xrel_info.%sStatesDWorkName = '''';', lPrefix);
                writer.wLine('xrel_info.%sStatesDWorkType = '''';', lPrefix);
                writer.wLine('xrel_info.%sStatesDWorkTag = '''';', lPrefix);
            else
                writer.wLine('xrel_info.%sStatesDWorkName = ''%s'';', lPrefix, lDW.Implementation.Identifier);
                writer.wLine('xrel_info.%sStatesDWorkType = ''%s'';', lPrefix, lDW.Implementation.Type.Identifier);
                writer.wLine('xrel_info.%sStatesDWorkTag = ''%s'';', lPrefix, lDW.Implementation.Type.Name);
            end
        end
    end
    
end