classdef AUTOSARPortInfoSerializer < coder.internal.xrelexport.PortInfoSerializer
    % AUTOSARPORTINFOSERIALIZER
    %
    % Copyright 2017 The MathWorks, Inc.
    methods
        function obj = AUTOSARPortInfoSerializer(port_list, xrelmsg)
            % AUTOSARPORTINFOSERIALIZER
            %   Use superclass's initializer
            obj = obj@coder.internal.xrelexport.PortInfoSerializer(port_list, xrelmsg);
        end
    end
    
    methods (Access = protected)
        function writeSimulinkFunctions(obj, writer, top_level_struct)
            % WRITESIMULINKFUNCTIONS
            %
            % Override writeSimulinkFunctions for AUTOSAR
            num_simulinkfunctions = obj.PortList.NumSimulinkFunctions;
            for kFcn = 1:num_simulinkfunctions
                lObject = obj.PortList.getSimulinkFunction(kFcn);
                lPrefixStr = sprintf('%s.%s(%u)',  ...
                    top_level_struct, obj.SimulinkFunctionsFieldName, kFcn);
                lFieldList = {'CGFunctionName', 'AUTOSAROperationName', ...
                    'AUTOSARPortName', 'IsCalled', 'IsDefined'};
                for lField = lFieldList
                    writer.wLine('%s.%s = ''%s'';', lPrefixStr, ...
                        lField{:}, lObject.(lField{:}));
                end
            end
        end
        
        function writeAUTOSARPortInfo(obj, writer, top_level_struct, idx, port, ports_field_name)
            % WRITEAUTOSARPORTINFO
            writer.wLine('%s.%s(%u).AutosarPort = %s;', ...
                    top_level_struct, ports_field_name, idx, obj.escapeGraphicalName(port.AUTOSARPort));
                writer.wLine('%s.%s(%u).AutosarDataElement = %s;', ...
                    top_level_struct, ports_field_name, idx, obj.escapeGraphicalName(port.AUTOSARDataElement));
                writer.wLine('%s.%s(%u).AutosarReceiverPortNumber = ''%s'';', ...
                    top_level_struct, ports_field_name, idx, port.AUTOSARReceiverPortNumber);
                
                if port.IsQueued
                    lIsQueued = 'true';
                else
                    lIsQueued = 'false';
                end
                writer.wLine('%s.%s(%u).IsQueued = %s;', ...
                    top_level_struct, ports_field_name, idx, lIsQueued);
                
                writer.wLine('%s.%s(%u).QueueLength = %d;', ...
                    top_level_struct, ports_field_name, idx, port.QueueLength);
                
                writer.wLine('%s.%s(%u).DataAccessMode = ''%s'';', ...
                    top_level_struct, ports_field_name, idx, port.DataAccessMode);
        end
    end
end